==> meteor-bootstrap_key-value-tag-input-3.0.3.tgz: package/src/keyValueTypes/TagKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
function stringToTag(value) {
    return { value: value, display: { text: value } };
}
function isTags(tags) {
    return tags.length === 0 || typeof tags[0] !== "string";
}
var TagKeyValueType = /** @class */ (function (_super) {
    __extends(TagKeyValueType, _super);
    function TagKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._tags = [];
        _this._allowOther = false;
        return _this;
    }
    Object.defineProperty(TagKeyValueType.prototype, "tags", {
        set: function (tags) {
            if (isTags(tags)) {
                this._tags = tags;
            }
            else {
                this._tags = tags.map(stringToTag);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagKeyValueType.prototype, "allowOther", {
        set: function (allowOther) {
            this._allowOther = allowOther;
        },
        enumerable: true,
        configurable: true
    });
    TagKeyValueType.prototype.getSuggestions = function (prefix, entries, defaultEntries, allowDuplicates) {
        var _this = this;
        var substringLower = prefix.toLowerCase();
        var tags = this._tags.filter(function (t) { var _a; return t.value.toLowerCase().includes(substringLower) || ((_a = t.editString) === null || _a === void 0 ? void 0 : _a.toLowerCase().includes(substringLower)); });
        if (!allowDuplicates) {
            tags = tags.filter(function (t) {
                return entries.every(function (e) { return e.type === _this && !_this.isValueEqual(t, e.value); }) &&
                    defaultEntries.every(function (e) { return e.type === _this && !_this.isValueEqual(t, e.value); });
            });
        }
        return tags.map(function (t) { return ({
            display: t.display,
            match: prefix !== "" ?
                (t.value.toLowerCase().includes(substringLower) ? t.value : t.editString)
                : undefined,
            value: t.value,
        }); });
    };
    TagKeyValueType.prototype.parseString = function (val) {
        var value = val.trim().toLowerCase();
        var tag = this._tags.find(function (t) { var _a; return t.value.toLowerCase() === value || ((_a = t.editString) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === value; });
        if (tag) {
            return tag;
        }
        if (this._allowOther && val.trim() !== "") {
            return stringToTag(val.trim());
        }
    };
    TagKeyValueType.prototype.checkValue = function (val) {
        if (typeof val === "string") {
            return this.parseString(val);
        }
        else {
            return undefined;
        }
    };
    TagKeyValueType.prototype.display = function (value) {
        return value.display;
    };
    TagKeyValueType.prototype.editText = function (value) {
        var _a;
        return _a = value.editString, (_a !== null && _a !== void 0 ? _a : value.value);
    };
    TagKeyValueType.prototype.isValueEqual = function (valueA, valueB) {
        if (_super.prototype.isValueEqual.call(this, valueA, valueB)) {
            return true;
        }
        if (valueA && valueB) {
            return valueA.value === valueB.value;
        }
        return false;
    };
    return TagKeyValueType;
}(KeyValueType));
export default TagKeyValueType;

==> meteor-bootstrap_key-value-tag-input-3.1.0.tgz: package/src/keyValueTypes/TagKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
function stringToTag(value) {
    return { value: value, display: { text: value } };
}
function isTags(tags) {
    return tags.length === 0 || typeof tags[0] !== "string";
}
var TagKeyValueType = /** @class */ (function (_super) {
    __extends(TagKeyValueType, _super);
    function TagKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._tags = [];
        _this._allowOther = false;
        return _this;
    }
    Object.defineProperty(TagKeyValueType.prototype, "tags", {
        set: function (tags) {
            if (isTags(tags)) {
                this._tags = tags;
            }
            else {
                this._tags = tags.map(stringToTag);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagKeyValueType.prototype, "allowOther", {
        set: function (allowOther) {
            this._allowOther = allowOther;
        },
        enumerable: true,
        configurable: true
    });
    TagKeyValueType.prototype.getSuggestions = function (prefix, entries, defaultEntries, allowDuplicates) {
        var _this = this;
        var substringLower = prefix.toLowerCase();
        var tags = this._tags.filter(function (t) { var _a; return t.value.toLowerCase().includes(substringLower) || ((_a = t.editString) === null || _a === void 0 ? void 0 : _a.toLowerCase().includes(substringLower)); });
        if (!allowDuplicates) {
            tags = tags.filter(function (t) {
                return entries.every(function (e) { return e.type === _this && !_this.isValueEqual(t, e.value); }) &&
                    defaultEntries.every(function (e) { return e.type === _this && !_this.isValueEqual(t, e.value); });
            });
        }
        return tags.map(function (t) {
            var _a;
            return ({
                display: _this.display(t),
                match: prefix !== "" ?
                    ((_a = t.editString, (_a !== null && _a !== void 0 ? _a : "")).toLowerCase().includes(substringLower) ? t.editString : t.value)
                    : undefined,
                value: t.value,
            });
        });
    };
    TagKeyValueType.prototype.parseString = function (val) {
        var value = val.trim().toLowerCase();
        var tag = this._tags.find(function (t) { var _a; return t.value.toLowerCase() === value || ((_a = t.editString) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === value; });
        if (tag) {
            return tag;
        }
        if (this._allowOther && val.trim() !== "") {
            return stringToTag(val.trim());
        }
    };
    TagKeyValueType.prototype.checkValue = function (val) {
        if (typeof val === "string") {
            return this.parseString(val);
        }
        else {
            return undefined;
        }
    };
    TagKeyValueType.prototype.display = function (value) {
        var _a, _b;
        return _a = value.display, (_a !== null && _a !== void 0 ? _a : { text: (_b = value.editString, (_b !== null && _b !== void 0 ? _b : value.value)) });
    };
    TagKeyValueType.prototype.editText = function (value) {
        var _a;
        return _a = value.editString, (_a !== null && _a !== void 0 ? _a : value.value);
    };
    TagKeyValueType.prototype.isValueEqual = function (valueA, valueB) {
        if (_super.prototype.isValueEqual.call(this, valueA, valueB)) {
            return true;
        }
        if (valueA && valueB) {
            return valueA.value === valueB.value;
        }
        return false;
    };
    return TagKeyValueType;
}(KeyValueType));
export default TagKeyValueType;
